@@ -9,12 +9,13 @@ Elasticsearch store.
 from __future__ import absolute_import
 
 import json
-from urllib import urlencode
-from urllib2 import urlopen
 
+from six.moves.urllib.parse import urlencode
+from six.moves.urllib.request import urlopen
+
+from cytoolz import identity, pipe
 import nltk
 import spotlight
-from toolz import identity, pipe
 
 from .es import fetch
 from ..core import app
